@@ -1,9 +1,10 @@
 from django import forms
 from django.test import TestCase
 from django.utils.translation import ugettext_lazy as _
+from django.utils import six
 
 from .fields import PluginChoiceField, PluginModelChoiceField, \
-                    PluginModelMultipleChoiceField
+    PluginModelMultipleChoiceField
 from .point import PluginMount, PluginPoint
 from .models import Plugin, PluginPoint as PluginPointModel
 from .models import ENABLED, DISABLED, REMOVED
@@ -35,9 +36,9 @@ class PluginSyncTestCaseBase(TestCase):
 
     def prepate_query_sets(self):
         self.points = PluginPointModel.objects.filter(
-                        pythonpath='djangoplugins.tests.MyPluginPoint')
+            pythonpath='djangoplugins.tests.MyPluginPoint')
         self.plugins = Plugin.objects.filter(
-                        pythonpath='djangoplugins.tests.MyPlugin')
+            pythonpath='djangoplugins.tests.MyPlugin')
 
 
 class PluginSyncTestCase(PluginSyncTestCaseBase):
@@ -67,7 +68,6 @@ class PluginSyncTestCase(PluginSyncTestCaseBase):
                          plugin_model.pythonpath)
 
 
-
 class PluginSyncRemovedTestCase(PluginSyncTestCaseBase):
     def setUp(self):
         self.prepate_query_sets()
@@ -106,18 +106,18 @@ class PluginModelsTest(TestCase):
     def test_plugin_model(self):
         plugin_name = 'djangoplugins.tests.MyPlugin'
         plugin = Plugin.objects.get(pythonpath=plugin_name)
-        self.assertEqual(plugin_name, unicode(plugin))
+        self.assertEqual(plugin_name, six.text_type(plugin))
         self.assertEqual((plugin_name,), plugin.natural_key())
 
     def test_plugin_model_full(self):
         plugin_name = 'djangoplugins.tests.MyPluginFull'
         plugin = Plugin.objects.get(pythonpath=plugin_name)
-        self.assertEqual(_('My Plugin Full'), unicode(plugin))
+        self.assertEqual(_('My Plugin Full'), six.text_type(plugin))
 
     def test_plugin_point_model(self):
         point_name = 'djangoplugins.tests.MyPluginPoint'
         point = PluginPointModel.objects.get(pythonpath=point_name)
-        self.assertEqual('MyPluginPoint', unicode(point))
+        self.assertEqual('MyPluginPoint', six.text_type(point))
 
     def test_plugins_of_plugin(self):
         self.assertRaises(Exception, MyPlugin.get_plugins_qs)
@@ -192,17 +192,17 @@ class MyTestForm(forms.Form):
     plugin_choice = PluginChoiceField(MyPluginPoint)
     model_choice = PluginModelChoiceField(MyPluginPoint)
 
-    #plugin_multi_choice = PluginMultipleChoiceField(MyPluginPoint)
+    # plugin_multi_choice = PluginMultipleChoiceField(MyPluginPoint)
     model_multi_choice = PluginModelMultipleChoiceField(MyPluginPoint)
 
 
 class PluginsFieldsTest(TestCase):
     def test_validation(self):
         form = MyTestForm({
-                'plugin_choice': 'my-plugin-2',
-                'model_choice': '%d' % MyPlugin2.get_model().id,
-        #        'plugin_multi_choice': ['my-plugin-2'],
-                'model_multi_choice': ['%d' % MyPlugin2.get_model().id],
+            'plugin_choice': 'my-plugin-2',
+            'model_choice': '%d' % MyPlugin2.get_model().id,
+            # 'plugin_multi_choice': ['my-plugin-2'],
+            'model_multi_choice': ['%d' % MyPlugin2.get_model().id],
             })
         self.assertTrue(form.is_valid())
 
